@@ -1,6 +1,6 @@
-pub mod event_loop;
+pub mod engine;
 pub mod renderer;
 pub mod traits;
 pub mod vertex;
 
-pub use glium as backend;
+pub use glium as backend;
\ No newline at end of file
